Crate surface_wasmtime

Crate surface_wasmtime 

Structs

Surface
SurfaceCtx
SurfaceDesc

Traits

MainThreadSpawner
Runs main-thread-only operations, as required by some operating systems (e.g. macOS). On platforms without that requirement the implementation may run them in place.
SurfaceCtxView

Functions

add_surface_to_linker